# foss42

[![Discord Server Invite](https://img.shields.io/badge/DISCORD-JOIN%20SERVER-5663F7?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/2s49SCNfyJ)
![PyPI](https://img.shields.io/pypi/v/foss42?logo=python&logoColor=yellow&style=for-the-badge)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/foss42?logo=python&logoColor=yellow&style=for-the-badge)

Core Python library for foss42 Open Source APIs. 

To learn more about the project check out:
- [foss42 Home Page (foss42.com)](https://foss42.com)
- [GitHub Organization Page](https://github.com/foss42) 

## Installation

```
pip3 install foss42
```

## Testing

Install `pytest`

```
$ pip3 install pytest
```

Clone the repo, set it as the current working directory and run the tests using the command:

```
$ pytest
```